import { buildRequestParams } from "./../helpers/index.mjs";
import { useRuntimeConfig } from "#imports";
function getEndpoint(operation, operationName) {
  const config = useRuntimeConfig();
  return `${config?.public?.["nuxt-graphql-middleware"]?.serverApiPrefix}/${operation}/${operationName}`;
}
const state = {
  fetchOptions: {}
};
export const useGraphqlState = function() {
  return state;
};
function performRequest(operation, operationName, method, options) {
  const state2 = useGraphqlState();
  return $fetch(getEndpoint(operation, operationName), {
    ...state2 && state2.fetchOptions ? state2.fetchOptions : {},
    ...options,
    method
  }).then((v) => {
    return {
      data: v.data,
      errors: v.errors || []
    };
  });
}
export function useGraphqlQuery(...args) {
  const [name, variables, fetchOptions = {}] = typeof args[0] === "string" ? [args[0], args[1]] : [args[0].name, args[0].variables, args[0].fetchOptions];
  return performRequest("query", name, "get", {
    params: buildRequestParams(variables),
    ...fetchOptions
  });
}
export function useGraphqlMutation(...args) {
  const [name, body, fetchOptions = {}] = typeof args[0] === "string" ? [args[0], args[1]] : [args[0].name, args[0].variables, args[0].fetchOptions];
  return performRequest("mutation", name, "post", {
    body,
    ...fetchOptions
  });
}
